/* Modal for Shell Selection */
ModalScreen{
    align:center middle;
}

#modal-shell-vert {
    layout:grid;
    width: 20%;
    height: auto;
    grid-size: 1;
    grid-columns: 1fr;
    grid-rows: 4;
    align:center middle;
    background: $panel;
    border:black thick;
}

#modal-shell-vert > Label {
    width: 1fr;
    content-align:center middle;
}
#modal-shell-vert > .shell {
    width: 1fr ;
    height: auto ;
    margin: 0 1 1 1;
    content-align:center middle;
}

#modal-shell-vert > Button {
    width: 1fr ;
    content-align:center middle;
}
